@@ -194,20 +194,27 @@ class TableMetadata:
         for column_name, column in self_columns_dict.items():
             merged_description = (
                 existing_columns_dict[column_name].description
-                if preserve_descriptions and column_name in existing_columns_dict
+                if column_name in existing_columns_dict
                 else column.description
             )
             merged_example = (
                 existing_columns_dict[column_name].example_value
-                if preserve_descriptions and column_name in existing_columns_dict
+                if column_name in existing_columns_dict
                 else column.example_value
             )
+
+            merged_values = (
+                existing_columns_dict[column_name].values
+                if column_name in existing_columns_dict and column.values is None
+                else column.values
+            )
+
             merged_columns.append(
                 ColumnMetadata(
                     name=column_name,
                     column_type=column.column_type,
                     description=merged_description,
-                    values=column.values,
+                    values=merged_values,
                     example_value=merged_example,
                 )
             )
@@ -217,15 +224,12 @@ class TableMetadata:
         self_tags_dict = self.get_tags_by_name()
         existing_tags_dict = existing.get_tags_by_name()
 
-        merged_tags = []
+        merged_tags = existing_tags_dict.copy()
 
         for key, value in self_tags_dict.items():
-            merged_value = (
-                existing_tags_dict[key] if key in existing_tags_dict else value
-            )
-            merged_tags.append(TableTag(key=key, value=merged_value))
+            merged_tags[key] = value
 
-        return merged_tags
+        return [TableTag(key=key, value=value) for key, value in merged_tags.items()]
 
     def merge_with_existing(self, existing):
         if existing.name is not None and existing.name != self.name:
@@ -245,7 +249,7 @@ class TableMetadata:
             description=description,
             location=self.location,
             columns=self.merge_columns(existing),
-            tags=self.merge_columns(existing),
+            tags=self.merge_tags(existing),
             table_type=self.table_type,
         )
 
